Module: Nanoc::Core

Defined in:
lib/nanoc/core.rb,
lib/nanoc/core/item.rb,
lib/nanoc/core/site.rb,
lib/nanoc/core/view.rb,
lib/nanoc/core/error.rb,
lib/nanoc/core/store.rb,
lib/nanoc/core/utils.rb,
lib/nanoc/core/errors.rb,
lib/nanoc/core/filter.rb,
lib/nanoc/core/layout.rb,
lib/nanoc/core/pruner.rb,
lib/nanoc/core/content.rb,
lib/nanoc/core/context.rb,
lib/nanoc/core/feature.rb,
lib/nanoc/core/pattern.rb,
lib/nanoc/core/version.rb,
lib/nanoc/core/compiler.rb,
lib/nanoc/core/document.rb,
lib/nanoc/core/executor.rb,
lib/nanoc/core/item_rep.rb,
lib/nanoc/core/assertions.rb,
lib/nanoc/core/dependency.rb,
lib/nanoc/core/identifier.rb,
lib/nanoc/core/lazy_value.rb,
lib/nanoc/core/checksummer.rb,
lib/nanoc/core/data_source.rb,
lib/nanoc/core/site_loader.rb,
lib/nanoc/core/toml_loader.rb,
lib/nanoc/core/yaml_loader.rb,
lib/nanoc/core/code_snippet.rb,
lib/nanoc/core/instrumentor.rb,
lib/nanoc/core/snapshot_def.rb,
lib/nanoc/core/config_loader.rb,
lib/nanoc/core/configuration.rb,
lib/nanoc/core/core_ext/hash.rb,
lib/nanoc/core/item_rep_repo.rb,
lib/nanoc/core/trivial_error.rb,
lib/nanoc/core/binary_content.rb,
lib/nanoc/core/changes_stream.rb,
lib/nanoc/core/checksum_store.rb,
lib/nanoc/core/core_ext/array.rb,
lib/nanoc/core/directed_graph.rb,
lib/nanoc/core/regexp_pattern.rb,
lib/nanoc/core/string_pattern.rb,
lib/nanoc/core/action_provider.rb,
lib/nanoc/core/action_sequence.rb,
lib/nanoc/core/compiler_loader.rb,
lib/nanoc/core/core_ext/string.rb,
lib/nanoc/core/item_collection.rb,
lib/nanoc/core/item_rep_router.rb,
lib/nanoc/core/item_rep_writer.rb,
lib/nanoc/core/textual_content.rb,
lib/nanoc/core/dependency_props.rb,
lib/nanoc/core/dependency_store.rb,
lib/nanoc/core/item_rep_builder.rb,
lib/nanoc/core/compilation_stage.rb,
lib/nanoc/core/contracts_support.rb,
lib/nanoc/core/item_rep_selector.rb,
lib/nanoc/core/layout_collection.rb,
lib/nanoc/core/outdatedness_rule.rb,
lib/nanoc/core/processing_action.rb,
lib/nanoc/core/views/config_view.rb,
lib/nanoc/core/views/layout_view.rb,
lib/nanoc/core/dependency_tracker.rb,
lib/nanoc/core/outdatedness_store.rb,
lib/nanoc/core/processing_actions.rb,
lib/nanoc/core/checksum_collection.rb,
lib/nanoc/core/compilation_context.rb,
lib/nanoc/core/document_view_mixin.rb,
lib/nanoc/core/notification_center.rb,
lib/nanoc/core/outdatedness_status.rb,
lib/nanoc/core/outdatedness_checker.rb,
lib/nanoc/core/outdatedness_reasons.rb,
lib/nanoc/core/prefixed_data_source.rb,
lib/nanoc/core/action_sequence_store.rb,
lib/nanoc/core/aggregate_data_source.rb,
lib/nanoc/core/compiled_content_repo.rb,
lib/nanoc/core/in_memory_data_source.rb,
lib/nanoc/core/temp_filename_factory.rb,
lib/nanoc/core/views/basic_item_view.rb,
lib/nanoc/core/compiled_content_cache.rb,
lib/nanoc/core/structured_data_loader.rb,
lib/nanoc/core/view_context_for_shell.rb,
lib/nanoc/core/action_sequence_builder.rb,
lib/nanoc/core/identifiable_collection.rb,
lib/nanoc/core/views/mutable_item_view.rb,
lib/nanoc/core/compilation_stages/prune.rb,
lib/nanoc/core/processing_actions/filter.rb,
lib/nanoc/core/processing_actions/layout.rb,
lib/nanoc/core/views/basic_item_rep_view.rb,
lib/nanoc/core/views/mutable_config_view.rb,
lib/nanoc/core/views/mutable_layout_view.rb,
lib/nanoc/core/basic_outdatedness_checker.rb,
lib/nanoc/core/compilation_stages/cleanup.rb,
lib/nanoc/core/mutable_document_view_mixin.rb,
lib/nanoc/core/processing_actions/snapshot.rb,
lib/nanoc/core/views/compilation_item_view.rb,
lib/nanoc/core/view_context_for_compilation.rb,
lib/nanoc/core/views/layout_collection_view.rb,
lib/nanoc/core/views/post_compile_item_view.rb,
lib/nanoc/core/binary_compiled_content_cache.rb,
lib/nanoc/core/compilation_stages/build_reps.rb,
lib/nanoc/core/compilation_stages/preprocess.rb,
lib/nanoc/core/outdatedness_rules/item_added.rb,
lib/nanoc/core/compilation_stages/load_stores.rb,
lib/nanoc/core/compilation_stages/postprocess.rb,
lib/nanoc/core/outdatedness_rules/not_written.rb,
lib/nanoc/core/textual_compiled_content_cache.rb,
lib/nanoc/core/compilation_stages/compile_reps.rb,
lib/nanoc/core/outdatedness_rules/layout_added.rb,
lib/nanoc/core/views/compilation_item_rep_view.rb,
lib/nanoc/core/view_context_for_pre_compilation.rb,
lib/nanoc/core/views/post_compile_item_rep_view.rb,
lib/nanoc/core/outdatedness_rules/rules_modified.rb,
lib/nanoc/core/views/identifiable_collection_view.rb,
lib/nanoc/core/views/mutable_item_collection_view.rb,
lib/nanoc/core/outdatedness_rules/content_modified.rb,
lib/nanoc/core/views/basic_item_rep_collection_view.rb,
lib/nanoc/core/views/item_collection_with_reps_view.rb,
lib/nanoc/core/views/mutable_layout_collection_view.rb,
lib/nanoc/core/compilation_stages/calculate_checksums.rb,
lib/nanoc/core/outdatedness_rules/attributes_modified.rb,
lib/nanoc/core/views/item_collection_without_reps_view.rb,
lib/nanoc/core/views/post_compile_item_collection_view.rb,
lib/nanoc/core/compilation_stages/determine_outdatedness.rb,
lib/nanoc/core/outdatedness_rules/code_snippets_modified.rb,
lib/nanoc/core/views/compilation_item_rep_collection_view.rb,
lib/nanoc/core/views/mutable_identifiable_collection_view.rb,
lib/nanoc/core/views/post_compile_item_rep_collection_view.rb,
lib/nanoc/core/compilation_stages/store_pre_compilation_state.rb,
lib/nanoc/core/outdatedness_rules/uses_always_outdated_filter.rb,
lib/nanoc/core/compilation_stages/forget_outdated_dependencies.rb,
lib/nanoc/core/compilation_stages/store_post_compilation_state.rb

Defined Under Namespace

Modules: Assertions, CompilationStages, ContractsSupport, CoreExt, DocumentViewMixin, Errors, Feature, MutableDocumentViewMixin, OutdatednessReasons, OutdatednessRules, ProcessingActions, StructuredDataLoader, TomlLoader, Utils, YamlLoader Classes: ActionProvider, ActionSequence, ActionSequenceBuilder, ActionSequenceStore, AggregateDataSource, BasicItemRepCollectionView, BasicItemRepView, BasicItemView, BasicOutdatednessChecker, BinaryCompiledContentCache, BinaryContent, ChangesStream, ChecksumCollection, ChecksumStore, Checksummer, CodeSnippet, CompilationContext, CompilationItemRepCollectionView, CompilationItemRepView, CompilationItemView, CompilationStage, CompiledContentCache, CompiledContentRepo, Compiler, CompilerLoader, ConfigLoader, ConfigView, Configuration, Content, Context, DataSource, Dependency, DependencyProps, DependencyStore, DependencyTracker, DirectedGraph, Document, Error, Executor, Filter, IdentifiableCollection, IdentifiableCollectionView, Identifier, InMemoryDataSource, Instrumentor, Item, ItemCollection, ItemCollectionWithRepsView, ItemCollectionWithoutRepsView, ItemRep, ItemRepBuilder, ItemRepRepo, ItemRepRouter, ItemRepSelector, ItemRepWriter, Layout, LayoutCollection, LayoutCollectionView, LayoutView, LazyValue, MutableConfigView, MutableIdentifiableCollectionView, MutableItemCollectionView, MutableItemView, MutableLayoutCollectionView, MutableLayoutView, NotificationCenter, OutdatednessChecker, OutdatednessRule, OutdatednessStatus, OutdatednessStore, Pattern, PostCompileItemCollectionView, PostCompileItemRepCollectionView, PostCompileItemRepView, PostCompileItemView, PrefixedDataSource, ProcessingAction, Pruner, RegexpPattern, Site, SiteLoader, SnapshotDef, Store, StringPattern, TempFilenameFactory, TextualCompiledContentCache, TextualContent, TrivialError, View, ViewContextForCompilation, ViewContextForPreCompilation, ViewContextForShell

Constant Summary collapse

UNDEFINED =

Similar to nil except that it can only be compared against using UNDEFINED.equal?(x). Used in places where nil already has meaning, and thus cannot be used to mean the presence of nothing.

Object.new
VERSION =
'4.14.8'

Class Method Summary collapse

Class Method Details

.on_windows?Boolean

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns True if the current platform is Windows, false otherwise.

Returns:

  • (Boolean)

    True if the current platform is Windows, false otherwise.



56
57
58
# File 'lib/nanoc/core.rb', line 56

def self.on_windows?
  @_on_windows ||= TTY::Platform.new.windows?
end

.version_informationString

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns A string containing information about this Nanoc version and its environment (Ruby engine and version, Rubygems version if any).

Returns:

  • (String)

    A string containing information about this Nanoc version and its environment (Ruby engine and version, Rubygems version if any).



48
49
50
51
# File 'lib/nanoc/core.rb', line 48

def self.version_information
  "Nanoc #{Nanoc::Core::VERSION} © 2007–… Denis Defreyne.\n" \
    "Running #{RUBY_ENGINE} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} with RubyGems #{Gem::VERSION}.\n"
end