Exception: Nanoc::Core::Errors::UnknownDataSource

Inherits:
Nanoc::Core::Error show all
Defined in:
lib/nanoc/core/errors.rb

Overview

Error that is raised when a site is loaded that uses a data source with an unknown identifier.

Instance Method Summary collapse

Constructor Details

#initialize(data_source_name) ⇒ UnknownDataSource

Returns a new instance of UnknownDataSource.

Parameters:

  • data_source_name (String)

    The data source name for which no data source could be found



52
53
54
55
56
# File 'lib/nanoc/core/errors.rb', line 52

def initialize(data_source_name)
  super(
    'The data source specified in the site’s configuration file, ' \
    "#{data_source_name}”, does not exist.")
end