Module: Nanoc::Core::OutdatednessReasons Private

Defined in:
lib/nanoc/core/outdatedness_reasons.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Module that contains all outdatedness reasons.

API:

  • private

Defined Under Namespace

Classes: AttributesModified, DocumentAdded, Generic

Constant Summary collapse

CodeSnippetsModified =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'The code snippets have been modified since the last time the site ' \
  'was compiled.',
  Nanoc::Core::DependencyProps.new(
    raw_content: true, attributes: true,
    compiled_content: true, path: true
  ),
)
DependenciesOutdated =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'This item uses content or attributes that have changed since the ' \
  'last time the site was compiled.',
)
NotWritten =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'This item representation has not yet been written to the output ' \
  'directory (but it does have a path).',
  Nanoc::Core::DependencyProps.new(
    raw_content: true, attributes: true,
    compiled_content: true, path: true
  ),
)
RulesModified =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'The rules file has been modified since the last time the site was ' \
  'compiled.',
  Nanoc::Core::DependencyProps.new(compiled_content: true, path: true),
)
ContentModified =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'The content of this item has been modified since the last time ' \
  'the site was compiled.',
  Nanoc::Core::DependencyProps.new(
    raw_content: true, compiled_content: true,
  ),
)
UsesAlwaysOutdatedFilter =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

API:

  • private

Generic.new(
  'This item rep uses one or more filters that cannot track ' \
  'dependencies, and will thus always be considered as outdated.',
  Nanoc::Core::DependencyProps.new(
    raw_content: true, attributes: true, compiled_content: true,
  ),
)