Exception: Nanoc::Core::Errors::UnknownDataSource
- Inherits:
-
Nanoc::Core::Error
- Object
- StandardError
- Nanoc::Core::Error
- Nanoc::Core::Errors::UnknownDataSource
- Defined in:
- lib/nanoc/core/errors.rb
Overview
Error that is raised when a site is loaded that uses a data source with an unknown identifier.
Instance Method Summary collapse
-
#initialize(data_source_name) ⇒ UnknownDataSource
constructor
A new instance of UnknownDataSource.
Constructor Details
#initialize(data_source_name) ⇒ UnknownDataSource
Returns a new instance of UnknownDataSource.
52 53 54 55 56 |
# File 'lib/nanoc/core/errors.rb', line 52 def initialize(data_source_name) super( 'The data source specified in the site’s configuration file, ' \ "“#{data_source_name}”, does not exist.") end |